@@ -1,7 +1,7 @@
 package Yukki::Role::Savable;
-$Yukki::Role::Savable::VERSION = '0.991_006'; # TRIAL
-
-$Yukki::Role::Savable::VERSION = '0.991006';use v5.24;
+$Yukki::Role::Savable::VERSION = '0.991_007'; # TRIAL
+$Yukki::Role::Savable::VERSION = '0.991007';
+use v5.24;
 use utf8;
 use Moo::Role;
 
@@ -60,7 +60,7 @@ Yukki::Role::Savable - Provides a mechanism for YAML-izing objects
 
 =head1 VERSION
 
-version 0.991_006
+version 0.991_007
 
 =head1 SYNOPSIS
 
@@ -114,7 +114,7 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Qubling Software LLC.
+This software is copyright (c) 2026 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
