@@ -1,7 +1,7 @@
 package Yukki::Settings;
-$Yukki::Settings::VERSION = '0.991_006'; # TRIAL
-
-$Yukki::Settings::VERSION = '0.991006';use v5.24;
+$Yukki::Settings::VERSION = '0.991_007'; # TRIAL
+$Yukki::Settings::VERSION = '0.991007';
+use v5.24;
 use utf8;
 use Moo;
 
@@ -77,9 +77,9 @@ has repositories => (
 
 {
     package Yukki::Settings::Anonymous;
-$Yukki::Settings::Anonymous::VERSION = '0.991_006'; # TRIAL
-
-$Yukki::Settings::Anonymous::VERSION = '0.991006';use Moo;
+$Yukki::Settings::Anonymous::VERSION = '0.991_007'; # TRIAL
+$Yukki::Settings::Anonymous::VERSION = '0.991007';
+use Moo;
     use Types::Standard qw( Str );
     use Yukki::Types qw( EmailAddress );
 
@@ -122,7 +122,7 @@ Yukki::Settings - provides structure and validation to settings in yukki.conf
 
 =head1 VERSION
 
-version 0.991_006
+version 0.991_007
 
 =head1 DESCRIPTION
 
@@ -206,7 +206,7 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Qubling Software LLC.
+This software is copyright (c) 2026 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
