@@ -1,7 +1,7 @@
 package Yukki::Web::View::Attachment;
-$Yukki::Web::View::Attachment::VERSION = '0.991_006'; # TRIAL
-
-$Yukki::Web::View::Attachment::VERSION = '0.991006';use v5.24;
+$Yukki::Web::View::Attachment::VERSION = '0.991_007'; # TRIAL
+$Yukki::Web::View::Attachment::VERSION = '0.991007';
+use v5.24;
 use utf8;
 use Moo;
 
@@ -90,7 +90,7 @@ Yukki::Web::View::Attachment - View for attachment forms
 
 =head1 VERSION
 
-version 0.991_006
+version 0.991_007
 
 =head1 DESCRIPTION
 
@@ -112,7 +112,7 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Qubling Software LLC.
+This software is copyright (c) 2026 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
