@@ -1,7 +1,7 @@
 package Yukki::Web::View::Role::Navigation;
-$Yukki::Web::View::Role::Navigation::VERSION = '0.991_006'; # TRIAL
-
-$Yukki::Web::View::Role::Navigation::VERSION = '0.991006';use v5.24;
+$Yukki::Web::View::Role::Navigation::VERSION = '0.991_007'; # TRIAL
+$Yukki::Web::View::Role::Navigation::VERSION = '0.991007';
+use v5.24;
 use Moo::Role;
 
 use String::Errf qw( errf );
@@ -40,7 +40,7 @@ Yukki::Web::View::Role::Navigation - Common page navigation tools for views
 
 =head1 VERSION
 
-version 0.991_006
+version 0.991_007
 
 =head1 DESCRIPTION
 
@@ -91,7 +91,7 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Qubling Software LLC.
+This software is copyright (c) 2026 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
